@@ -14,6 +14,7 @@ import argparse
 import json
 import os
 import sys
+import webbrowser
 
 import paramiko
 import pkg_resources
@@ -60,7 +61,7 @@ def sort_reviews_by_last_updated(reviews):
 
 
 def votes_by_name(review):
-    """Return a dict of votes like {'name': -1}"""
+    """Return a dict of votes like {'name': -1}."""
     return dict([(_name(x['by']), int(x['value']))
                  for x in review['currentPatchSet'].get('approvals', [])])
 
@@ -157,19 +158,6 @@ def ignore_wip(reviews):
     return [x for x in reviews if x['status'] != 'WORKINPROGRESS']
 
 
-def which(program):
-    """Locates a program file in the user's path."""
-    for path in os.environ['PATH'].split(":"):
-        if os.path.exists(path + '/' + program):
-            return path + '/' + program
-
-
-def open_url(url):
-    """Opens a URL using whatever program is available on the system."""
-    open_app = which('xdg-open') or 'open'
-    os.system('%s %s' % (open_app, url))
-
-
 def main(args):
     client = ssh_client(
         host=args.host, port=args.port, user=args.username, key=args.key)
@@ -199,7 +187,7 @@ def main(args):
         render_reviews(reviews, maximum=1)
 
         # open the oldest code review in a browser
-        open_url(reviews[0]['url'])
+        webbrowser.open(reviews[0]['url'])
     else:
         print 'Nothing to review!'
 
